cli

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type App

type App struct {
	// contains filtered or unexported fields
}

App runs the page subcommands against a Confluence client.

func New

func New(client page.Client, stdout io.Writer) *App

New constructs a CLI app with the provided output writer.

func NewLazy

func NewLazy(clientLoader func() (page.Client, error), stdout io.Writer) *App

NewLazy constructs a CLI app that resolves a client only when needed.

func (*App) Run

func (a *App) Run(ctx context.Context, args []string, workdir string) int

Run executes the requested page command.

Jump to